﻿
function Install-WebPart {
    [CmdletBinding()]
    param(
        [Parameter(Mandatory=$true)]
		$wspPath, #path to Virto.KanbanTaskManager.wsp

		[Parameter(Mandatory=$true)]
        [string]
		$webAppURL  # URL of web application
    )
	Add-PSSnapin Microsoft.SharePoint.PowerShell
    $solutionName = 'Virto.KanbanTaskManager.wsp'
	$featuresId = 'ac9e18b1-eae7-404f-9309-e2e477d1db58','aa033dfa-848f-40bf-a9ec-50a8b1aa0af2'

	$solution = Get-SPSolution -Identity $solutionName  -ErrorAction SilentlyContinue
	$solutionNotExist = -not($solution)
	if ($solutionNotExist) {
		Add-SPSolution $wspPath
		Write-Host 'Solution is added'
	}
	if (-not($solutionNotExist)) {
		 Write-Host 'Solution is already added' -ForegroundColor Yellow
	}

	Write-Host 'Start deploy'

	Install-SPSolution -Identity Virto.KanbanTaskManager.wsp -GACDeployment  -WebApplication $webAppURL  -Force
	$solution = Get-SPSolution -Identity $solutionName  -ErrorAction SilentlyContinue
	while ($solution.JobExists -eq $true) 
	{
		Write-Host '.' -NoNewline
		sleep -Seconds:1
		$solution = Get-SPSolution -Identity $solutionName  -ErrorAction SilentlyContinue
	}
	Write-Host $solution.JobStatus
	Write-Host 'Deployed'


	$indx = 0
	$webApp = Get-SPWebApplication  $webAppURL  
	foreach($siteColl in $webApp.Sites)  
	{  
		try
		{
			$indx++
			Write-Host $indx $siteColl.Url -ForegroundColor Green
			foreach ($featureId in $featuresId)
			{
				$feature = $siteColl.Features[$featureId]
				if($feature.TimeActivated -eq $null)
				{
					Enable-SPFeature -identity $featureId -URL $siteColl.Url
					Write-Host "`tFeature is activated " $featureId -ForegroundColor Green
				}
				if($feature.TimeActivated -ne $null)
				{
					Write-Host "`tFeature already activated " $featureId  -ForegroundColor Yellow
				}
			}
		}
		catch
		{
  			Write-Host $error[0].Exception  -ForegroundColor Red -BackgroundColor Yellow
		}
	}  
}




#Example
#Install-WebPart C:\temp\Virto.KanbanBoard.Setup\Virto.KanbanTaskManager.wsp http://sp2019.virtosoftware.com



